# Python automation for the Bartels Mikrotechnik labtronix micropump driver

## Installation
`pip install pybartelslabtronix`

## Usage
[See Jupyter Notebook for example usage.](notebooks/Test_Bartels_Labtronix.ipynb)
